==> haskell-unordered-containers-0.2.9.0-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unordered-containers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unordered-containers
version: 0.2.9.0
id: unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd
key: unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd
license: BSD-3-Clause
copyright: 2010-2014 Johan Tibell
           2010 Edward Z. Yang
maintainer: johan.tibell@gmail.com
author: Johan Tibell
homepage: https://github.com/tibbe/unordered-containers
synopsis: Efficient hashing-based container types
description:
    Efficient hashing-based container types.  The containers have been
    optimized for performance critical use, both in terms of large data
    quantities and high speed.
    .
    The declared cost of each operation is either worst-case or
    amortized, but remains valid even if structures are shared.
category: Data
abi: 4d1dd6bd73dbf55dc13ef767664a6e82
exposed: True
exposed-modules:
    Data.HashMap.Lazy Data.HashMap.Strict Data.HashSet
hidden-modules: Data.HashMap.Array Data.HashMap.Base
                Data.HashMap.List Data.HashMap.Unsafe Data.HashMap.UnsafeShift
import-dirs: /usr/lib/ghc-8.4.3/site-local/unordered-containers-0.2.9.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/unordered-containers-0.2.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/unordered-containers-0.2.9.0
hs-libraries: HSunordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd
depends:
    base-4.11.1.0 deepseq-1.4.3.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
haddock-interfaces: /usr/share/doc/haskell-unordered-containers/html/unordered-containers.haddock
haddock-html: /usr/share/doc/haskell-unordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unordered-containers-0.2.9.0-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unordered-containers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unordered-containers
version: 0.2.9.0
id: unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa
key: unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa
license: BSD-3-Clause
copyright: 2010-2014 Johan Tibell
           2010 Edward Z. Yang
maintainer: johan.tibell@gmail.com
author: Johan Tibell
homepage: https://github.com/tibbe/unordered-containers
synopsis: Efficient hashing-based container types
description:
    Efficient hashing-based container types.  The containers have been
    optimized for performance critical use, both in terms of large data
    quantities and high speed.
    .
    The declared cost of each operation is either worst-case or
    amortized, but remains valid even if structures are shared.
category: Data
abi: 81e1d2b217f05c2ba43642acf6d96f3b
exposed: True
exposed-modules:
    Data.HashMap.Lazy Data.HashMap.Strict Data.HashSet
hidden-modules: Data.HashMap.Array Data.HashMap.Base
                Data.HashMap.List Data.HashMap.Unsafe Data.HashMap.UnsafeShift
import-dirs: /usr/lib/ghc-8.4.3/site-local/unordered-containers-0.2.9.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/unordered-containers-0.2.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/unordered-containers-0.2.9.0
hs-libraries: HSunordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa
depends:
    base-4.11.1.0 deepseq-1.4.3.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
haddock-interfaces: /usr/share/doc/haskell-unordered-containers/html/unordered-containers.haddock
haddock-html: /usr/share/doc/haskell-unordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
